
#include <gtk/gtk.h>


/**
 *  Show an input box to enter a string value.
 *  If the dialog is aborted, @c value remains untouched.
 *
 *  @param title The dialog title.
 *  @param label_text The shown dialog label.
 *  @param default_value The default value for the entry, maybe NULL or an empty string.
 *  @param value The return location for the entered text. This must be non-NULL, the value will
 *         be written into this location and must be freed when no longer needed.
 *
 *  @return @a TRUE if a value was entered and the dialog closed with 'OK'. @a FALSE otherwise.
 *
 *  @since 0.18
 **/
gboolean dialogs_show_input_string(const gchar *title, const gchar *label_text,
								   const gchar *default_value, gchar **result)
{
	GtkWidget *dialog, *label, *entry, *vbox;
	gboolean res = FALSE;

	g_return_val_if_fail(title != NULL, FALSE);
	g_return_val_if_fail(label_text != NULL, FALSE);
	g_return_val_if_fail(result != NULL, FALSE);

	dialog = gtk_dialog_new_with_buttons(title, GTK_WINDOW(main_widgets.window),
										GTK_DIALOG_DESTROY_WITH_PARENT,
										GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
										GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, NULL);
	gtk_dialog_set_default_response(GTK_DIALOG(dialog), GTK_RESPONSE_CANCEL);
	vbox = ui_dialog_vbox_new(GTK_DIALOG(dialog));
	gtk_widget_set_name(dialog, "GeanyDialog");

	label = gtk_label_new(label_text);
	gtk_misc_set_alignment(GTK_MISC(label), 0, 0.5);

	entry = gtk_entry_new();
	if (NZV(default_value))
		gtk_entry_set_text(GTK_ENTRY(entry), default_value);
	ui_entry_add_clear_icon(entry);

	gtk_container_add(GTK_CONTAINER(vbox), label);
	gtk_container_add(GTK_CONTAINER(vbox), entry);
	gtk_widget_show_all(vbox);

	if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_ACCEPT)
	{
		*result = g_strdup(gtk_entry_get_text(GTK_ENTRY(entry)));
		res = TRUE;
	}
	gtk_widget_destroy(dialog);

	return res;
}


int main(int argc, char** argv)
{
	gchar *value;
	if (dialogs_show_input_string("Test Dialog", "Enter some text", "", &value))
	{
		g_message("entered string: %s", value);
		g_free(value);
	}

	return 0;
}
